**********************************
Welcome to United's documentation!
**********************************

A SI unit representation and conversion tool.


Contents
========

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   api
   authors
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
